==============================================================
``psyclone.tests.psyir.frontend.fparser2_generate_psyir_test``
==============================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_generate_psyir_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_generate_psyir_test
